# wksort
A Lib realizes different sort methods

1.To get Methods Names use :  wksort.names()
2.To return Methods result use: wksort.<methodName>(list, parm)
3.Methods speed test
4.Methods rank by speed/space